@@ -29,7 +29,7 @@ setClass("Hub",
     # find snapshot date
     if (!localHub){
         tryCatch({
-            db_date <- .restrictDateByVersion(db_path)
+            db_date <- .restrictDateByVersion(db_path, proxy)
         }, error=function(err) {
             stop("failed to connect",
                  "\n  reason: ", conditionMessage(err),
@@ -47,7 +47,7 @@ setClass("Hub",
     if(interactive()){
         message("snapshotDate(): ", snapshotDate(hub))
     }
-    
+
     if (!localHub){
         index <- .db_create_index(hub)
         .db_index(hub) <- index
@@ -127,6 +127,7 @@ setReplaceMethod("isLocalHub", "Hub",
     function(x, value)
 {
     stopifnot(value %in% c(TRUE, FALSE))
+    proxy <- .getProxyValue(x)
     # not a no op
     if (isLocalHub(x) != value){
         # switch from FALSE to TRUE
@@ -136,7 +137,7 @@ setReplaceMethod("isLocalHub", "Hub",
         # switch from TRUE to FALSE
         }else{
             db_path <- x@.db_path
-            db_date <- .restrictDateByVersion(db_path)
+            db_date <- .restrictDateByVersion(db_path, proxy)
             db_uid <- .db_uid0(db_path, db_date, value)
             x <- new(as.character(class(x)), cache=hubCache(x), hub=hubUrl(x),
                      date=db_date, .db_path=db_path, .db_uid=db_uid,
@@ -159,9 +160,10 @@ setReplaceMethod("snapshotDate", "Hub",
     }, error=function(err) {
         stop("'value' must be a single date or character string")
     })
+    proxy <- .getProxyValue(x)
 
     ## 'value' must be < BiocManager::version() release date
-    restrict <- .restrictDateByVersion(dbfile(x))
+    restrict <- .restrictDateByVersion(dbfile(x), proxy)
     dates <- .possibleDates(dbfile(x))
     valid_range <- range(dates[as.POSIXlt(dates) <= as.POSIXlt(restrict)])
     if (as.POSIXlt(value) > max(valid_range) ||
@@ -253,13 +255,13 @@ setMethod("[", c("Hub", "character", "missing"),
 })
 
 setMethod("[[", c("Hub", "numeric", "missing"),
-    function(x, i, j, ..., force=FALSE, verbose=TRUE)
+    function(x, i, j, ..., force=FALSE, verbose=TRUE, config=list(), progress=TRUE)
 {
-    .Hub_get1(x[i], force=force, verbose=verbose)
+    .Hub_get1(x[i], force=force, verbose=verbose, config=config, progress=progress)
 })
 
 setMethod("[[", c("Hub", "character", "missing"),
-    function(x, i, j, ..., force=FALSE, verbose=TRUE)
+    function(x, i, j, ..., force=FALSE, verbose=TRUE, config=list(), progress=TRUE)
 {
     if (length(i) != 1L)
         stop("'i' must be length 1")
@@ -297,7 +299,7 @@ setMethod("[[", c("Hub", "character", "missing"),
             msg <- paste0(msg, "   Resource removed on: ", status$dateremoved)
         stop(msg, call.=FALSE)
     }
-    .Hub_get1(x[idx], force=force, verbose=verbose)
+    .Hub_get1(x[idx], force=force, verbose=verbose, config=config, progress=progress)
 })
 
 
@@ -306,10 +308,10 @@ setMethod("[[", c("Hub", "character", "missing"),
 ###
 
 setMethod("cache", "Hub",
-    function(x, ..., proxy, max.downloads, force=FALSE, verbose=FALSE)
+    function(x, ..., proxy, max.downloads, config=list(), progress=TRUE, force=FALSE, verbose=FALSE)
         .cache_internal(x,
                         proxy=proxy, max.downloads=max.downloads,
-                        force=force, verbose=verbose)
+                        force=force, verbose=verbose, config=config, progress=progress)
 )
 
 
@@ -345,7 +347,8 @@ setReplaceMethod("cache", "Hub",
     localHub <- isLocalHub(x)
     db_path <- x@.db_path
     if (!localHub){
-        db_date <- .restrictDateByVersion(db_path)
+        proxy <- .getProxyValue(x)
+        db_date <- .restrictDateByVersion(db_path, proxy)
     } else {
         dates <-.possibleDates(db_path)
         db_date <- dates[length(dates)]
@@ -419,7 +422,8 @@ setMethod("removeResources", "character",
                 localHub <- isLocalHub(hub)
                 db_path <- hub@.db_path
                 if (!localHub){
-                    db_date <- .restrictDateByVersion(db_path)
+                    proxy <- .getProxyValue(hub)
+                    db_date <- .restrictDateByVersion(db_path, proxy)
                 } else {
                     dates <-.possibleDates(db_path)
                     db_date <- dates[length(dates)]
@@ -499,7 +503,10 @@ getSize <- function(hub, tbl)
     vapply(urls,
            FUN=function(url){
                tryCatch({
-                   headers(HEAD(url))$`content-length`
+                   response = request(url) %>% req_method("HEAD") %>% req_perform()
+                   ifelse(resp_header_exists(response, "content-length"),
+                          resp_header(response, "content-length"),
+                          NA_character_)
                }, error = function(err){
                    NA_character_
                })
@@ -665,20 +672,6 @@ setMethod("show", "Hub", function(object)
         .show(object)
 })
 
-setMethod("display", signature(object="Hub"),
-    function(object) {
-        .Defunct(
-            "BiocHubsShiny", "BiocHubsShiny",
-            c(
-                "'display,Hub-method' is deprecated.\n",
-                "Use 'BiocHubsShiny::BiocHubsShiny' instead.\n",
-                "See help(\"AnnotationHub-deprecated\")"
-            )
-        )
-    }
-)
-
-
 setMethod("recordStatus", "Hub",
     function(hub, record) {
         if (!is.character(record))
